const packager = require('electron-packager');
const path = require('path');
const pjson = require('../package.json');

const currentDir = process.cwd();
const args = process.argv.splice(2);
const platformArg = args[0];

let platform;

if (platformArg === '--platform=macos') {
  platform = 'darwin';
}

if (platformArg === '--platform=windows') {
  platform = 'win32';
}

packager(
  {
    dir: currentDir,
    out: path.join(currentDir, 'built'),
    icon: path.join(currentDir, 'icon/app'),
    platform,
    arch: 'x64',
    appVersion: pjson.version,
    ignore: [
      /\.ts$/,
      /\.tsx$/,
      /app/,
      /playbooks/,
      /\.eslintrc/,
      /\.gitignore/,
      /\.nvmrc/,
      /\.prettierrc/,
      /ansible.cfg/,
      /hosts/,
      /README.md/,
      /tsconfig.json/,
      /webpack.config.json/,
      /yarn.lock/,
    ],
  },
  error => {
    if (error) {
      // eslint-disable-next-line no-console
      console.log(error);

      process.exit(1);
    }
  }
);
