const path = require('path');
const { merge } = require('webpack-merge');
const ForkTsCheckerWebpackPlugin = require('fork-ts-checker-webpack-plugin');

const env = process.env.NODE_ENV;

const appConfig = {
  mode: env || 'development',
  entry: [path.resolve('app', 'index.tsx')],
  output: {
    path: path.resolve('dist'),
    filename: 'bundle.js',
  },
  resolve: {
    modules: [path.resolve('app'), 'node_modules'],
    alias: {
      'react-dom': '@hot-loader/react-dom',
      config: path.resolve('electron/config'),
    },
    extensions: ['.ts', '.tsx', '.js', '.jsx'],
  },
  target: 'electron-renderer',
  module: {
    rules: [
      {
        test: /\.ts(x?)$/,
        exclude: [/node_modules/],
        use: {
          loader: 'babel-loader',
          options: {
            cacheDirectory: true,
            babelrc: false,
            presets: [
              ['@babel/preset-env', { targets: { browsers: 'last 1 version' } }],
              '@babel/preset-typescript',
              '@babel/preset-react',
            ],
            plugins: ['@babel/plugin-transform-runtime', 'react-hot-loader/babel'],
          },
        },
      },
      {
        test: /\.css$/,
        include: [path.resolve('node_modules/devicon')],
        use: ['style-loader', 'css-loader'],
      },
      {
        test: /\.(jpg|png|ttf|eot|svg|woff2|woff)$/,
        type: 'asset/inline',
      },
    ],
  },
};

const developmentConfig = {
  output: {
    publicPath: 'http://localhost:8080/',
  },
  plugins: [new ForkTsCheckerWebpackPlugin()],
  devtool: 'eval-source-map',
};

const productionConfig = {
  output: {
    publicPath: '/',
  },
  // TODO: don't know why but need to works with webpack 5
  devtool: 'eval',
};

module.exports = merge(appConfig, env === 'production' ? productionConfig : developmentConfig);
